#!/bin/sh
#################################################################
#								#
#  sybinstall.sh	Sybase Adaptive Server Enterprise	#
#								#
#  Script to administrate and configure your Sybase ASE		#
#  installation for the 1st time.  Create a system account	#
#  and have installation permissions set to the release.	#
#								#
#  RPM can tell us where the ASE components are installed.	#
#  queryformat on the 'installprefix' will provide the		#
#  correct location if it was relocated into an other area.	#
#								#
#################################################################
export PATH="/etc:/bin:/sbin:/usr/bin:/usr/sbin:$PATH"

# Are we invoked with an argument (RPM native) or is this a manual request.
if [ "${1}" ]; then
    if [ -f $1/install/sybinstall.sh ]; then
	export SYBASE=$1
    fi
else
    PREFIX=`rpm -q sybase-common`
    if [ "$PREFIX" ]; then
	export SYBASE=`rpm -q --queryformat '%{installprefix}' $PREFIX`
    fi
fi

if [ "${SYBASE}" ]; then

    # Place the end-user LICENSE and README files
    if [ ! -r ${SYBASE}/LICENSE ]; then
	if [ -f ${SYBASE}/install/LICENSE ]; then
	    ( cd $SYBASE; ln -sf install/LICENSE LICENSE )
	fi
    fi
    if [ ! -r ${SYBASE}/README ]; then
	if [ -f ${SYBASE}/install/README ]; then
	    ( cd $SYBASE; ln -sf install/README README )
	fi
    fi
    if [ ! -s $SYBASE/SYSAM-1_0/licenses/license.dat ]; then
	cp -f $SYBASE/Installer-1_1/lib/default.lic \
	    $SYBASE/SYSAM-1_0/licenses/license.dat
    fi

    # Profide a sybase boot script under /etc/rc.d/init.d
    # only if this was not done previously.
    if [ -d /etc/rc.d/init.d -a ! -r /etc/rc.d/init.d/sybase ]; then
	cp ${SYBASE}/install/rc.sybase /etc/rc.d/init.d/sybase
    	chmod 555 /etc/rc.d/init.d/sybase
    fi

    # Provide a .profile and .cshrc from the install directory,
    # only if this was not done previously.
    if [ ! -r ${SYBASE}/.profile ]; then
	( cd $SYBASE; ln -sf install/profile .profile )
    fi
    if [ ! -r ${SYBASE}/.cshrc ]; then
	( cd $SYBASE; ln -sf install/cshrc .cshrc )
    fi

    # Provide execute permissions on the above scripts.
    chmod 755 ${SYBASE}/.profile ${SYBASE}/.cshrc

    # Is this a NIS based installation, yes -> use ypmatch over grep
    ypwhich > /dev/null 2>&1
    NIS_INSTALL=$?

    if [ ${NIS_INSTALL} = 0 ]; then

	NIS_SYB_GRP=`ypmatch "sybase" group  | grep "^sybase:" | \
			tr ':' ' ' | awk '{ print $3 }'` > /dev/null
	NIS_SYB_USR=`ypmatch "sybase" passwd | grep "^sybase:" | \
			tr ':' ' ' | awk '{ print $3 }'` > /dev/null
    fi

    SYB_GRP=`grep "^sybase:" /etc/group` > /dev/null
    SYB_USR=`grep "^sybase:" /etc/passwd` > /dev/null

    if [ ! "${SYB_GRP}" ]; then
	if [ "${NIS_SYB_GRP}" ]; then
		groupadd -g ${NIS_SYB_GRP} sybase -f
	else
		groupadd sybase
	fi
    fi

    if [ ! "${SYB_USR}" ]; then
	if [ "${NIS_SYB_USR}" ]; then
	   # We need to add a NIS record in the local passwd for
	   # home administration pointing to the release area.
		ypmatch sybase passwd >> /etc/passwd
	else
		useradd -g sybase -d ${SYBASE} \
			-c "Sybase ASE DBA account" sybase
	fi
    fi
    usermod -d ${SYBASE} sybase

    # Remove Linux user setup arrangements.
    rm -f ${SYBASE}/.bash*

    # Create short links for release component directories
    # only if this was not done previously.
    if [ ! -L ${SYBASE}/SYSAM -a -d ${SYBASE}/SYSAM-1_0 ]; then
	( cd ${SYBASE}; \
		ln -sf SYSAM-1_0 SYSAM; \
	  cd ${SYBASE}/SYSAM; \
		ln -sf ../install/SYSAM.csh SYSAM.csh; \
		ln -sf ../install/SYSAM.sh SYSAM.sh )
    fi
    if [ ! -L ${SYBASE}/Installer -a -d ${SYBASE}/Installer-1_1 ]; then
	( cd ${SYBASE}; ln -sf Installer-1_1 Installer )
    fi
    if [ ! -L ${SYBASE}/shared -a -d ${SYBASE}/shared-1_0 ]; then
	( cd ${SYBASE}; ln -sf shared-1_0 shared )
    fi
    if [ ! -L ${SYBASE}/ASE -a -d ${SYBASE}/ASE-12_5 ]; then
	( cd ${SYBASE}; \
		ln -sf ASE-12_5 ASE; \
	  cd ${SYBASE}/ASE; \
		ln -sf ../install/ASE.csh ASE.csh; \
		ln -sf ../install/ASE.sh ASE.sh )
    fi
    if [ ! -L ${SYBASE}/OCS -a -d ${SYBASE}/OCS-12_5 ]; then
	( cd ${SYBASE}; \
		ln -sf OCS-12_5 OCS; \
	  cd ${SYBASE}/OCS; \
		ln -sf ../install/OCS.csh OCS.csh; \
		ln -sf ../install/OCS.sh OCS.sh )
    fi

    # Add links for SYBASE environment setup
    # only if this was not done previously.
    if [ ! -r ${SYBASE}/SYBASE.csh ]; then
	ln -sf ${SYBASE}/install/SYBASE.csh ${SYBASE}/SYBASE.csh
    fi
    if [ ! -r ${SYBASE}/SYBASE.sh ]; then
	ln -sf ${SYBASE}/install/SYBASE.sh ${SYBASE}/SYBASE.sh
    fi

    if [ -d ${SYBASE} ]; then
 	chown -R sybase.sybase ${SYBASE}
	chmod ug+w `find ${SYBASE} -type d -print`
	chmod -f u+w ${SYBASE}/SYSAM*/licenses/license.dat \
 		${SYBASE}/OCS*/config/libtcl.cfg
    fi

    if [ -d ${SYBASE}/sysam/licenses -a -x ${SYBASE}/install/demokey.sh ]; then
	if [ ! -s ${SYBASE}/sysam/licenses/license.dat ]; then
		echo "\n\. \${SYBASE}/install/demokey.sh" >> $SYBASE/.profile
	fi
    fi

    # Indicate that the readme and srvbuild process can be triggered.
    touch ${SYBASE}/.readme

    exit 0
fi

exit 1
